summaryrefslogtreecommitdiffstats
path: root/smb4k/browser/smb4knetworkbrowser_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/browser/smb4knetworkbrowser_part.h')
-rw-r--r--smb4k/browser/smb4knetworkbrowser_part.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/smb4k/browser/smb4knetworkbrowser_part.h b/smb4k/browser/smb4knetworkbrowser_part.h
index c4710f9..78cc7fb 100644
--- a/smb4k/browser/smb4knetworkbrowser_part.h
+++ b/smb4k/browser/smb4knetworkbrowser_part.h
@@ -67,11 +67,11 @@ class Smb4KNetworkBrowserPart : public KParts::Part
/**
* The constructor.
*
- * @param parentWidget The tqparent widget
+ * @param parentWidget The parent widget
*
* @param widgetName The name the widget should have
*
* @param tqparent The tqparent object
*
* @param name The name this object should have
*
@@ -79,7 +79,7 @@ class Smb4KNetworkBrowserPart : public KParts::Part
*/
Smb4KNetworkBrowserPart( TQWidget *parentWidget = 0,
const char *widgetName = 0,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0,
Mode mode = Normal );
@@ -174,7 +174,7 @@ class Smb4KNetworkBrowserPart : public KParts::Part
/**
* This slot receives the list of workgroup/domain members that were found
* by the scanner. It takes this @p list and inserts it into the list view.
* The tqparent of the items is the workgroup/domain item with the name
* @p workgroup. Obsolete items will be deleted from the network browser.
*
* @param workgroup The workgroup where the hosts belong
@@ -340,11 +340,11 @@ class Smb4KNetworkBrowserPartFactory : public KParts::Factory
* Reimplemented from KParts::Factory. This function is used to
* create a part object.
*
- * @param parentWidget The tqparent of the part's widget.
+ * @param parentWidget The parent of the part's widget.
*
* @param widgetName The name of the part's widget.
*
* @param tqparent The tqparent of the part.
*
* @param name The name of the part.
*
@@ -356,7 +356,7 @@ class Smb4KNetworkBrowserPartFactory : public KParts::Factory
* konqplugin="true"|"false".
*/
virtual KParts::Part *createPartObject( TQWidget *parentWidget, const char *widgetName,
- TQObject *tqparent, const char *name,
+ TQObject *parent, const char *name,
const char *classname, const TQStringList &args = TQStringList() );
/**
@@ -67,11 +67,11 @@ class Smb4KNetworkBrowserPart : public KParts::Part
* @param widgetName The name the widget should have
*
- * @param tqparent The tqparent object
+ * @param parent The parent object
*
* @param name The name this object should have
@@ -174,7 +174,7 @@ class Smb4KNetworkBrowserPart : public KParts::Part
* This slot receives the list of workgroup/domain members that were found
* by the scanner. It takes this @p list and inserts it into the list view.
- * The tqparent of the items is the workgroup/domain item with the name
+ * The parent of the items is the workgroup/domain item with the name
* @p workgroup. Obsolete items will be deleted from the network browser.
*
@@ -340,11 +340,11 @@ class Smb4KNetworkBrowserPartFactory : public KParts::Factory
* @param widgetName The name of the part's widget.
*
- * @param tqparent The tqparent of the part.
+ * @param parent The parent of the part.
*
* @param name The name of the part.